@@ -6,4 +6,6 @@ from .summarisation import Summarisation
 from .text_vectorisation import TextVectorisation
 from .text_generation import TextGeneration
 from .emotion import Emotion
-from .image_classification import ImageClassification
\ No newline at end of file
+from .image_classification import ImageClassification
+from .image_vectorisation import ImageVectorisation
+from .image_text_vectorisation import ImageTextVectorisation
\ No newline at end of file
