@@ -1,12 +1,15 @@
-from backprop.models import BaseModel
+from typing import List, Dict
 import dill
 import pkg_resources
 import os
 import json
 
-def save(model, path=None):
+def save(model, name: str = None, description: str = None, tasks: List[str] = None, details: Dict = None, path=None):
     """
-    Saves the provided model to the backprop cache folder using model.name or to provided path
+    Saves the provided model to the backprop cache folder using:
+        1. provided name
+        2. model.name
+        3. provided path
 
     The resulting folder has three files:
 
@@ -15,11 +18,38 @@ def save(model, path=None):
         * requirements.txt (exact python runtime requirements)
 
     Args:
+        model: Model object
+        name: string identifier for the model. Lowercase letters and numbers.
+            No spaces/special characters except dashes.
+        description: String description of the model.
+        tasks: List of supported task strings
+        details: Valid json dictionary of additional details about the model
         path: Optional path to save model
+
+    Example::
+
+        import backprop
+
+        backprop.save(model_object, "my_model")
+        model = backprop.load("my_model")
     """
+
+    if name:
+        model.name = name
+
+    if description:
+        model.description = description
+
+    if tasks:
+        model.tasks = tasks
+
+    if details:
+        model.details = details
+
     name = model.name
     tasks = model.tasks
     description = model.description
+    details = model.details
 
     if hasattr(model.model, "eval"):
         model.model.eval()
@@ -34,10 +64,11 @@ def save(model, path=None):
 
     config = {
         "description": description,
-        "tasks": tasks
+        "tasks": tasks,
+        "details": details
     }
 
-    packages = ["backprop", "transformers", "sentence_transformers", "pytorch_lightning", "efficientnet_pytorch"]
+    packages = ["backprop", "transformers", "sentence_transformers", "efficientnet_pytorch"]
     requirements = [f"{package}=={pkg_resources.get_distribution(package).version}"
                     for package in packages]
 
